@@ -36,7 +36,7 @@ __all__ = [
 class FramesLengthError(CustomOverflowError):
     def __init__(
         self, func: FuncExceptT,
-        var_name: str, message: str = '"{var_name}" can\'t be greater than the clip length!',
+        var_name: str, message: SupportsString = '"{var_name}" can\'t be greater than the clip length!',
         **kwargs: Any
     ) -> None:
         super().__init__(message, func, var_name=var_name, **kwargs)
@@ -50,7 +50,7 @@ class VariableFormatError(CustomValueError):
     """Raised when clip is of a variable format."""
 
     def __init__(
-        self, func: FuncExceptT, message: str = 'Variable-format clips not supported!',
+        self, func: FuncExceptT, message: SupportsString = 'Variable-format clips not supported!',
         **kwargs: Any
     ) -> None:
         super().__init__(message, func, **kwargs)
@@ -60,7 +60,7 @@ class VariableResolutionError(CustomValueError):
     """Raised when clip is of a variable resolution."""
 
     def __init__(
-        self, func: FuncExceptT, message: str = 'Variable-resolution clips not supported!',
+        self, func: FuncExceptT, message: SupportsString = 'Variable-resolution clips not supported!',
         **kwargs: Any
     ) -> None:
         super().__init__(message, func, **kwargs)
@@ -75,7 +75,7 @@ class InvalidVideoFormatError(CustomValueError):
 
     def __init__(
         self, func: FuncExceptT, format: VideoFormatT | HoldsVideoFormatT,
-        message: str = 'The format {format.name} is not supported!',
+        message: SupportsString = 'The format {format.name} is not supported!',
         **kwargs: Any
     ) -> None:
         from ..utils import get_video_format
@@ -95,7 +95,7 @@ class InvalidColorFamilyError(CustomValueError):
         correct: VideoFormatT | HoldsVideoFormatT | vs.ColorFamily | Iterable[
             VideoFormatT | HoldsVideoFormatT | vs.ColorFamily
         ] = vs.YUV,
-        message: str = 'Input clip must be of {correct} color family, not {wrong}!',
+        message: SupportsString = 'Input clip must be of {correct} color family, not {wrong}!',
         **kwargs: Any
     ) -> None:
         from ..functions import to_arr
@@ -105,7 +105,7 @@ class InvalidColorFamilyError(CustomValueError):
 
         super().__init__(
             message, func, wrong=wrong_str,
-            correct=iter(set(get_color_family(c).name for c in to_arr(correct))), **kwargs
+            correct=iter(set(get_color_family(c).name for c in to_arr(correct))), **kwargs  # type: ignore[arg-type]
         )
 
     @staticmethod
@@ -114,7 +114,7 @@ class InvalidColorFamilyError(CustomValueError):
         correct: VideoFormatT | HoldsVideoFormatT | vs.ColorFamily | Iterable[
             VideoFormatT | HoldsVideoFormatT | vs.ColorFamily
         ],
-        func: FuncExceptT | None = None, message: str | None = None,
+        func: FuncExceptT | None = None, message: SupportsString | None = None,
         **kwargs: Any
     ) -> None:
         from ..functions import to_arr
@@ -137,7 +137,7 @@ class InvalidSubsamplingError(CustomValueError):
 
     def __init__(
         self, func: FuncExceptT, subsampling: str | VideoFormatT | HoldsVideoFormatT,
-        message: str = 'The subsampling {subsampling} is not supported!',
+        message: SupportsString = 'The subsampling {subsampling} is not supported!',
         **kwargs: Any
     ) -> None:
         from ..utils import get_video_format
@@ -149,7 +149,7 @@ class FormatsMismatchError(CustomValueError):
     """Raised when clips with different formats are given."""
 
     def __init__(
-        self, func: FuncExceptT, message: str = 'The format of both clips must be equal!',
+        self, func: FuncExceptT, message: SupportsString = 'The format of both clips must be equal!',
         **kwargs: Any
     ) -> None:
         super().__init__(message, func, **kwargs)
@@ -159,7 +159,7 @@ class FormatsRefClipMismatchError(FormatsMismatchError):
     """Raised when a ref clip and the main clip have different formats"""
 
     def __init__(
-        self, func: FuncExceptT, message: str = 'The format of ref and main clip must be equal!',
+        self, func: FuncExceptT, message: SupportsString = 'The format of ref and main clip must be equal!',
         **kwargs: Any
     ) -> None:
         super().__init__(func, message, **kwargs)
@@ -169,7 +169,7 @@ class ResolutionsMismatchError(CustomValueError):
     """Raised when clips with different resolutions are given."""
 
     def __init__(
-        self, func: FuncExceptT, message: str = 'The resolution of both clips must be equal!',
+        self, func: FuncExceptT, message: SupportsString = 'The resolution of both clips must be equal!',
         **kwargs: Any
     ) -> None:
         super().__init__(message, func, **kwargs)
@@ -179,7 +179,7 @@ class ResolutionsRefClipMismatchError(ResolutionsMismatchError):
     """Raised when a ref clip and the main clip have different resolutions"""
 
     def __init__(
-        self, func: FuncExceptT, message: str = 'The resolution of ref and main clip must be equal!',
+        self, func: FuncExceptT, message: SupportsString = 'The resolution of ref and main clip must be equal!',
         **kwargs: Any
     ) -> None:
         super().__init__(func, message, **kwargs)
@@ -189,7 +189,7 @@ class FramePropError(CustomKeyError):
     """Raised when there is an error with the frame props."""
 
     def __init__(
-        self, func: FuncExceptT, key: str, message: str = 'Error while trying to get frame prop "{key}"!',
+        self, func: FuncExceptT, key: str, message: SupportsString = 'Error while trying to get frame prop "{key}"!',
         **kwargs: Any
     ) -> None:
         super().__init__(message, func, key=key, **kwargs)
@@ -199,7 +199,7 @@ class TopFieldFirstError(CustomValueError):
     """Raised when the user must pass a TFF argument."""
 
     def __init__(
-        self, func: FuncExceptT, message: str = 'You must set `tff` for this clip!',
+        self, func: FuncExceptT, message: SupportsString = 'You must set `tff` for this clip!',
         **kwargs: Any
     ) -> None:
         super().__init__(message, func, **kwargs)
@@ -208,11 +208,11 @@ class TopFieldFirstError(CustomValueError):
 class InvalidFramerateError(CustomValueError):
     """Raised when the given clip has an invalid framerate."""
 
-    def __init__(
-        self, func: FuncExceptT, clip: vs.VideoNode | Fraction, message: str = '{fps} clips are not allowed!',
-        **kwargs: Any
-    ) -> None:
-        super().__init__(message, func, fps=clip.fps if isinstance(clip, vs.VideoNode) else clip, **kwargs)
+    def __init__(self, func: FuncExceptT, clip: vs.VideoNode | Fraction,
+                 message: SupportsString = '{fps} clips are not allowed!', **kwargs: Any) -> None:
+        super().__init__(
+            message, func, fps=clip.fps if isinstance(clip, vs.VideoNode) else clip, **kwargs  # type: ignore
+        )
 
     @staticmethod
     def check(
