@@ -2,9 +2,8 @@ from __future__ import annotations
 
 from typing import Any
 
+from ..types import FuncExceptT, SupportsString
 from .base import CustomError
-from ..types import SupportsString, FuncExceptT
-
 
 __all__ = [
     'CustomImportError',
@@ -16,17 +15,18 @@ class CustomImportError(CustomError, ImportError):
     """Raised when there's a general import error."""
 
     def __init__(
-        self, func: FuncExceptT, package: str, message: SupportsString = "Import failed for package '{package}'!",
+        self, func: FuncExceptT, package: str | ImportError,
+        message: SupportsString = "Import failed for package '{package}'!",
         **kwargs: Any
     ) -> None:
-        super().__init__(message, func, package=package, **kwargs)
+        super().__init__(message, func, package=package if isinstance(package, str) else package.name, **kwargs)
 
 
 class DependencyNotFoundError(CustomImportError):
     """Raised when there's a missing optional dependency."""
 
     def __init__(
-        self, func: FuncExceptT, package: str,
+        self, func: FuncExceptT, package: str | ImportError,
         message: SupportsString = "Missing dependency '{package}'!",
         **kwargs: Any
     ) -> None:
