@@ -5,13 +5,13 @@ from typing import Any, Iterable, Iterator, Sequence, overload
 
 import vapoursynth as vs
 
-from ..types import F, FrameRange, FrameRangeN, FrameRangesN, PlanesT, SupportsString, T
+from ..types import F, FrameRange, FrameRangeN, FrameRangesN, PlanesT, SupportsString, T, VideoNodeIterable
 
 __all__ = [
     'normalize_seq',
     'normalize_planes',
     'to_arr',
-    'flatten',
+    'flatten', 'flatten_vnodes',
     'normalize_franges',
     'normalize_ranges',
     'norm_func_name', 'norm_display_name'
@@ -61,12 +61,19 @@ def flatten(items: T | Iterable[T]) -> Iterable[T]:  # type: ignore
 
 
 def flatten(items: Any) -> Any:
-    for val in items:
-        if isinstance(val, Iterable) and not isinstance(val, (str, bytes)):
-            for sub_x in flatten(val):
-                yield sub_x
-        else:
-            yield val
+    if isinstance(items, (vs.RawNode, vs.RawFrame)):
+        yield items
+    else:
+        for val in items:
+            if isinstance(val, Iterable) and not isinstance(val, (str, bytes)):
+                for sub_x in flatten(val):
+                    yield sub_x
+            else:
+                yield val
+
+
+def flatten_vnodes(clips: VideoNodeIterable) -> list[vs.VideoNode]:
+    return list[vs.VideoNode](flatten(clips))  # type: ignore
 
 
 def normalize_franges(franges: FrameRange, /) -> Iterable[int]:
@@ -128,7 +135,7 @@ def norm_func_name(func_name: SupportsString | F) -> str:
 
     if callable(func):
         if hasattr(func, '__self__'):
-            func_name = f'{func.__self__.__name__}.{func_name}'  # type: ignore
+            func_name = f'{func.__self__.__name__}.{func_name}'
 
     return str(func_name).strip()
 
@@ -140,4 +147,7 @@ def norm_display_name(obj: object) -> str:
     if isinstance(obj, Fraction):
         return f'{obj.numerator}/{obj.denominator}'
 
+    if isinstance(obj, dict):
+        return '(' + ', '.join(f'{k}={v}' for k, v in obj.items()) + ')'
+
     return norm_func_name(obj)
