@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 from abc import abstractmethod
-from enum import Enum
 from typing import (
     Any, Callable, Iterable, ParamSpec, Protocol, Sequence, SupportsFloat, SupportsIndex, Tuple, TypeAlias, TypeVar,
     Union, overload, runtime_checkable
@@ -19,13 +18,14 @@ __all__ = [
 
     'Nb',
 
-    'PlanesT',
+    'PlanesT', 'VideoNodeIterable',
 
     'FrameRange', 'FrameRangeN', 'FrameRangesN',
 
-    'Self', 'SelfEnum',
+    'Self',
 
     'SingleOrArr', 'SingleOrArrOpt',
+    'SingleOrSeq', 'SingleOrSeqOpt',
 
     'SimpleByteData', 'SimpleByteDataArray',
     'ByteData',
@@ -85,11 +85,16 @@ FrameRange: TypeAlias = int | Tuple[int, int] | list[int]
 FrameRangeN: TypeAlias = int | Tuple[int | None, int | None] | None
 FrameRangesN: TypeAlias = list[FrameRangeN]
 
+VideoNodeIterable: TypeAlias = vs.VideoNode | Iterable[vs.VideoNode | Iterable[vs.VideoNode]] | Iterable[
+    vs.VideoNode | Iterable[vs.VideoNode | Iterable[vs.VideoNode]]
+]
+
 Self = TypeVar('Self')
-SelfEnum = TypeVar('SelfEnum', bound=Enum)
 
 SingleOrArr = Union[T, list[T]]
+SingleOrSeq = Union[T, Sequence[T]]
 SingleOrArrOpt = Union[SingleOrArr[T], None]
+SingleOrSeqOpt = Union[SingleOrSeq[T], None]
 
 SimpleByteData: TypeAlias = str | bytes | bytearray
 SimpleByteDataArray = Union[SimpleByteData, Sequence[SimpleByteData]]
