@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Iterable, List, overload
+from typing import TYPE_CHECKING, Any, Iterable, List, SupportsIndex, overload
 
 import vapoursynth as vs
 
@@ -25,10 +25,6 @@ class StrList(List[SupportsString]):
             ...
 
     @property
-    def string(self) -> str:
-        pass
-
-    @string.getter
     def string(self) -> str:
         return self.to_str()
 
@@ -46,3 +42,20 @@ class StrList(List[SupportsString]):
                 (str(x).strip() for x in flatten(self) if x is not None)  # type: ignore[var-annotated,arg-type]
             )
         )
+
+    def __add__(self, __x: list[SupportsString]) -> StrList:  # type: ignore[override]
+        return StrList(super().__add__(__x))
+
+    def __mul__(self, __n: SupportsIndex) -> StrList:
+        return StrList(super().__mul__(__n))
+
+    def __rmul__(self, __n: SupportsIndex) -> StrList:
+        return StrList(super().__rmul__(__n))
+
+    @property
+    def mlength(self) -> int:
+        return len(self) - 1
+
+    def append(self, *__object: SupportsString) -> None:
+        for __obj in __object:
+            super().append(__obj)
