@@ -28,7 +28,7 @@ __all__ = [
 def finalize_clip(
     clip: vs.VideoNode, bits: int | None = 10, clamp_tv_range: bool = True, *, func: FuncExceptT | None = None
 ) -> vs.VideoNode:
-    assert check_variable(clip, func)
+    assert check_variable(clip, func or finalize_clip)
 
     if bits:
         clip = depth(clip, bits)
@@ -95,9 +95,9 @@ def initialize_clip(
     field_based: FieldBasedT | None = FieldBased.PROGRESSIVE,
     strict: bool = False, *, func: FuncExceptT | None = None
 ) -> vs.VideoNode:
-    func = fallback(func, initialize_clip)
+    func = fallback(func, initialize_clip)  # type: ignore
 
-    values: list[tuple[PropEnum, int | PropEnum | None]] = [
+    values: list[tuple[type[PropEnum], Any]] = [
         (Matrix, matrix),
         (Transfer, transfer),
         (Primaries, primaries),
@@ -204,7 +204,7 @@ def initialize_input(
 @overload
 def chroma_injector(
     function: None = None, *,
-    scaler: Callable[[vs.VideoNode, int, int, int], vs.VideoNode] = vs.core.proxied.resize.Bicubic,
+    scaler: Callable[[vs.VideoNode, int, int, int], vs.VideoNode] = vs.core.lazy.resize.Bicubic,
     func: FuncExceptT | None = None
 ) -> Callable[[F_VD], F_VD]:
     ...
@@ -213,7 +213,7 @@ def chroma_injector(
 @overload
 def chroma_injector(
     function: F_VD, *,
-    scaler: Callable[[vs.VideoNode, int, int, int], vs.VideoNode] = vs.core.proxied.resize.Bicubic,
+    scaler: Callable[[vs.VideoNode, int, int, int], vs.VideoNode] = vs.core.lazy.resize.Bicubic,
     func: FuncExceptT | None = None
 ) -> F_VD:
     ...
@@ -221,7 +221,7 @@ def chroma_injector(
 
 def chroma_injector(
     function: F_VD | None = None, *,
-    scaler: Callable[[vs.VideoNode, int, int, int], vs.VideoNode] = vs.core.proxied.resize.Bicubic,
+    scaler: Callable[[vs.VideoNode, int, int, int], vs.VideoNode] = vs.core.lazy.resize.Bicubic,
     func: FuncExceptT | None = None
 ) -> Callable[[F_VD], F_VD] | F_VD:
     if function is None:
