@@ -28,7 +28,7 @@ def get_var_infos(frame: vs.VideoNode | vs.VideoFrame) -> tuple[vs.VideoFormat,
     if isinstance(frame, vs.VideoNode) and not (
         frame.width and frame.height and frame.format
     ):
-        frame = frame.get_frame(0)
+        frame = frame.get_frame(0)  # type: ignore
 
     assert frame.format
 
@@ -43,7 +43,7 @@ def get_video_format(
         sample_type = vs.SampleType(sample_type)
 
     if isinstance(value, vs.VideoFormat):
-        return value
+        return value  # type: ignore
 
     if isinstance(value, vs.PresetFormat):
         return vs.core.get_video_format(value)
@@ -57,12 +57,12 @@ def get_video_format(
 
         return vs.core.query_video_format(vs.YUV, sample_type, value)
 
-    assert value.format
+    assert value.format  # type: ignore
 
     if sample_type is not None:
-        return value.format.replace(sample_type=sample_type)
+        return value.format.replace(sample_type=sample_type)  # type: ignore
 
-    return value.format
+    return value.format  # type: ignore
 
 
 def get_depth(clip: VideoFormatT | HoldsVideoFormatT, /) -> int:
@@ -83,7 +83,7 @@ def get_color_family(clip: VideoFormatT | HoldsVideoFormatT | vs.ColorFamily, /)
 
 def get_framerate(clip: vs.VideoNode | Fraction | tuple[int, int] | float) -> Fraction:
     if isinstance(clip, vs.VideoNode):
-        return clip.fps
+        return clip.fps  # type: ignore
 
     if isinstance(clip, Fraction):
         return clip
@@ -91,7 +91,7 @@ def get_framerate(clip: vs.VideoNode | Fraction | tuple[int, int] | float) -> Fr
     if isinstance(clip, tuple):
         return Fraction(*clip)
 
-    return Fraction(clip)
+    return Fraction(clip)  # type: ignore
 
 
 def expect_bits(clip: vs.VideoNode, /, expected_depth: int = 16, **kwargs: Any) -> tuple[vs.VideoNode, int]:
@@ -162,9 +162,9 @@ def get_w(height: float, ref: vs.VideoNode | vs.VideoFrame, /) -> int:
 
 def get_w(height: float, ar_or_ref: vs.VideoNode | vs.VideoFrame | float = 16 / 9, /, mod: int | None = None) -> int:
     if isinstance(ar_or_ref, (vs.VideoNode, vs.VideoFrame)):
-        assert (ref := ar_or_ref).format
-        aspect_ratio = ref.width / ref.height
-        mod = 1 << ref.format.subsampling_w
+        assert (ref := ar_or_ref).format  # type: ignore
+        aspect_ratio = ref.width / ref.height  # type: ignore
+        mod = 1 << ref.format.subsampling_w  # type: ignore
     else:
         aspect_ratio = ar_or_ref
 
@@ -191,9 +191,9 @@ def get_h(width: float, ref: vs.VideoNode | vs.VideoFrame, /) -> int:
 
 def get_h(width: float, ar_or_ref: vs.VideoNode | vs.VideoFrame | float = 16 / 9, /, mod: int | None = None) -> int:
     if isinstance(ar_or_ref, (vs.VideoNode, vs.VideoFrame)):
-        assert (ref := ar_or_ref).format
-        aspect_ratio = ref.height / ref.width
-        mod = 1 << ref.format.subsampling_h
+        assert (ref := ar_or_ref).format  # type: ignore
+        aspect_ratio = ref.height / ref.width  # type: ignore
+        mod = 1 << ref.format.subsampling_h  # type: ignore
     else:
         aspect_ratio = ar_or_ref
 
