@@ -13,30 +13,24 @@ __all__ = [
     'GRAY8', 'GRAY9', 'GRAY10', 'GRAY11', 'GRAY12', 'GRAY13', 'GRAY14', 'GRAY15', 'GRAY16', 'GRAY17', 'GRAY18',
     'GRAY19', 'GRAY20', 'GRAY21', 'GRAY22', 'GRAY23', 'GRAY24', 'GRAY25', 'GRAY26', 'GRAY27', 'GRAY28', 'GRAY29',
     'GRAY30', 'GRAY31', 'GRAY32', 'GRAYH', 'GRAYS',
-    'YUV420P8', 'YUV420P9', 'YUV420P10', 'YUV420P11', 'YUV420P12',
-    'YUV420P13', 'YUV420P15', 'YUV420P16', 'YUV420P17', 'YUV420P18', 'YUV420P19', 'YUV420P20', 'YUV420P21', 'YUV420P22',
-    'YUV420P23', 'YUV420P24', 'YUV420P25', 'YUV420P26', 'YUV420P27', 'YUV420P28', 'YUV420P29', 'YUV420P30', 'YUV420P31',
-    'YUV420P32', 'YUV420PH', 'YUV420PS',
-    'YUV444P8', 'YUV444P9', 'YUV444P10', 'YUV444P11', 'YUV444P12', 'YUV444P13',
-    'YUV444P14', 'YUV444P15', 'YUV444P16', 'YUV444P17', 'YUV444P18', 'YUV444P19', 'YUV444P20', 'YUV444P21', 'YUV444P22',
-    'YUV444P23', 'YUV444P24', 'YUV444P25', 'YUV444P26', 'YUV444P27', 'YUV444P28', 'YUV444P29', 'YUV444P30', 'YUV444P31',
-    'YUV444P32', 'YUV444PH', 'YUV444PS',
-    'YUV422P8', 'YUV422P9', 'YUV422P10', 'YUV422P11', 'YUV422P12', 'YUV422P13',
-    'YUV422P14', 'YUV422P15', 'YUV422P16', 'YUV422P17', 'YUV422P18', 'YUV422P19', 'YUV422P20', 'YUV422P21', 'YUV422P22',
-    'YUV422P23', 'YUV422P24', 'YUV422P25', 'YUV422P26', 'YUV422P27', 'YUV422P28', 'YUV422P29', 'YUV422P30', 'YUV422P31',
-    'YUV422P32', 'YUV422PH', 'YUV422PS',
-    'YUV411P8', 'YUV411P9', 'YUV411P10', 'YUV411P11', 'YUV411P12', 'YUV411P13',
-    'YUV411P14', 'YUV411P15', 'YUV411P16', 'YUV411P17', 'YUV411P18', 'YUV411P19', 'YUV411P20', 'YUV411P21', 'YUV411P22',
-    'YUV411P23', 'YUV411P24', 'YUV411P25', 'YUV411P26', 'YUV411P27', 'YUV411P28', 'YUV411P29', 'YUV411P30', 'YUV411P31',
-    'YUV411P32', 'YUV411PH', 'YUV411PS',
-    'YUV440P8', 'YUV440P9', 'YUV440P10', 'YUV440P11', 'YUV440P12', 'YUV440P13',
-    'YUV440P14', 'YUV440P15', 'YUV440P16', 'YUV440P17', 'YUV440P18', 'YUV440P19', 'YUV440P20', 'YUV440P21', 'YUV440P22',
-    'YUV440P23', 'YUV440P24', 'YUV440P25', 'YUV440P26', 'YUV440P27', 'YUV440P28', 'YUV440P29', 'YUV440P30', 'YUV440P31',
-    'YUV440P32', 'YUV440PH', 'YUV440PS',
-    'YUV410P8', 'YUV410P9', 'YUV410P10', 'YUV410P11', 'YUV410P12', 'YUV410P13',
-    'YUV410P14', 'YUV410P15', 'YUV410P16', 'YUV410P17', 'YUV410P18', 'YUV410P19', 'YUV410P20', 'YUV410P21', 'YUV410P22',
-    'YUV410P23', 'YUV410P24', 'YUV410P25', 'YUV410P26', 'YUV410P27', 'YUV410P28', 'YUV410P29', 'YUV410P30', 'YUV410P31',
-    'YUV410P32', 'YUV410PH', 'YUV410PS',
+    'YUV420P8', 'YUV420P9', 'YUV420P10', 'YUV420P11', 'YUV420P12', 'YUV420P13', 'YUV420P14', 'YUV420P15', 'YUV420P16',
+    'YUV420P17', 'YUV420P18', 'YUV420P19', 'YUV420P20', 'YUV420P21', 'YUV420P22', 'YUV420P23', 'YUV420P24', 'YUV420P25',
+    'YUV420P26', 'YUV420P27', 'YUV420P28', 'YUV420P29', 'YUV420P30', 'YUV420P31', 'YUV420P32', 'YUV420PH', 'YUV420PS',
+    'YUV444P8', 'YUV444P9', 'YUV444P10', 'YUV444P11', 'YUV444P12', 'YUV444P13', 'YUV444P14', 'YUV444P15', 'YUV444P16',
+    'YUV444P17', 'YUV444P18', 'YUV444P19', 'YUV444P20', 'YUV444P21', 'YUV444P22', 'YUV444P23', 'YUV444P24', 'YUV444P25',
+    'YUV444P26', 'YUV444P27', 'YUV444P28', 'YUV444P29', 'YUV444P30', 'YUV444P31', 'YUV444P32', 'YUV444PH', 'YUV444PS',
+    'YUV422P8', 'YUV422P9', 'YUV422P10', 'YUV422P11', 'YUV422P12', 'YUV422P13', 'YUV422P14', 'YUV422P15', 'YUV422P16',
+    'YUV422P17', 'YUV422P18', 'YUV422P19', 'YUV422P20', 'YUV422P21', 'YUV422P22', 'YUV422P23', 'YUV422P24', 'YUV422P25',
+    'YUV422P26', 'YUV422P27', 'YUV422P28', 'YUV422P29', 'YUV422P30', 'YUV422P31', 'YUV422P32', 'YUV422PH', 'YUV422PS',
+    'YUV411P8', 'YUV411P9', 'YUV411P10', 'YUV411P11', 'YUV411P12', 'YUV411P13', 'YUV411P14', 'YUV411P15', 'YUV411P16',
+    'YUV411P17', 'YUV411P18', 'YUV411P19', 'YUV411P20', 'YUV411P21', 'YUV411P22', 'YUV411P23', 'YUV411P24', 'YUV411P25',
+    'YUV411P26', 'YUV411P27', 'YUV411P28', 'YUV411P29', 'YUV411P30', 'YUV411P31', 'YUV411P32', 'YUV411PH', 'YUV411PS',
+    'YUV440P8', 'YUV440P9', 'YUV440P10', 'YUV440P11', 'YUV440P12', 'YUV440P13', 'YUV440P14', 'YUV440P15', 'YUV440P16',
+    'YUV440P17', 'YUV440P18', 'YUV440P19', 'YUV440P20', 'YUV440P21', 'YUV440P22', 'YUV440P23', 'YUV440P24', 'YUV440P25',
+    'YUV440P26', 'YUV440P27', 'YUV440P28', 'YUV440P29', 'YUV440P30', 'YUV440P31', 'YUV440P32', 'YUV440PH', 'YUV440PS',
+    'YUV410P8', 'YUV410P9', 'YUV410P10', 'YUV410P11', 'YUV410P12', 'YUV410P13', 'YUV410P14', 'YUV410P15', 'YUV410P16',
+    'YUV410P17', 'YUV410P18', 'YUV410P19', 'YUV410P20', 'YUV410P21', 'YUV410P22', 'YUV410P23', 'YUV410P24', 'YUV410P25',
+    'YUV410P26', 'YUV410P27', 'YUV410P28', 'YUV410P29', 'YUV410P30', 'YUV410P31', 'YUV410P32', 'YUV410PH', 'YUV410PS',
     'RGB24', 'RGB27', 'RGB30', 'RGB33', 'RGB36', 'RGB39', 'RGB42', 'RGB45',
     'RGB48', 'RGB51', 'RGB54', 'RGB57', 'RGB60', 'RGB63', 'RGB66', 'RGB69', 'RGB72', 'RGB75', 'RGB78', 'RGB81',
     'RGB84', 'RGB87', 'RGB90', 'RGB93', 'RGB96', 'RGBH', 'RGBS'
@@ -95,6 +89,7 @@ class PresetFormat(PresetFormatBase):
     YUV420P11 = MAKE_VIDEO_ID(YUV, INTEGER, 11, 1, 1)
     YUV420P12 = MAKE_VIDEO_ID(YUV, INTEGER, 12, 1, 1)  # type: ignore[misc,assignment]
     YUV420P13 = MAKE_VIDEO_ID(YUV, INTEGER, 13, 1, 1)
+    YUV420P14 = MAKE_VIDEO_ID(YUV, INTEGER, 14, 1, 1)  # type: ignore[misc,assignment]
     YUV420P15 = MAKE_VIDEO_ID(YUV, INTEGER, 15, 1, 1)
     YUV420P16 = MAKE_VIDEO_ID(YUV, INTEGER, 16, 1, 1)  # type: ignore[misc,assignment]
     YUV420P17 = MAKE_VIDEO_ID(YUV, INTEGER, 17, 1, 1)
@@ -337,6 +332,7 @@ YUV420P10 = PresetFormat.YUV420P10
 YUV420P11 = PresetFormat.YUV420P11
 YUV420P12 = PresetFormat.YUV420P12
 YUV420P13 = PresetFormat.YUV420P13
+YUV420P14 = PresetFormat.YUV420P14
 YUV420P15 = PresetFormat.YUV420P15
 YUV420P16 = PresetFormat.YUV420P16
 YUV420P17 = PresetFormat.YUV420P17
